@@ -20,23 +20,25 @@
 
 #pragma once
 
+#include "tiled.h"
+
 #include <QColor>
 #include <QImage>
-#include <QString>
+#include <QUrl>
 
 namespace Tiled {
 
 class ImageReference
 {
 public:
-    ImageReference() : loaded(false) {}
+    ImageReference() : status(LoadingPending) {}
 
-    QString source;
+    QUrl source;
     QColor transparentColor;
     QSize size;
     QByteArray format;
     QByteArray data;
-    bool loaded;
+    LoadingStatus status;
 
     bool hasImage() const;
     QImage create() const;
